@@ -1,11 +1,12 @@
 context("ggplot: ggR, ggRGB & fortify")
+library(raster)
 
 test_that("ggR returns proper ggplot2 classes or data.frames", {
             data(rlogo) 
             
-            tests <- expand.grid(forceCat = c(TRUE, FALSE), anno = c(TRUE, FALSE), ggLayer = c(TRUE, FALSE), ggObj = c(TRUE,FALSE))
+            tests  <- expand.grid(forceCat = c(TRUE, FALSE), anno = c(TRUE, FALSE), ggLayer = c(TRUE, FALSE), ggObj = c(TRUE,FALSE))
             builds <- lapply(1:nrow(tests), function(i) ggR(rlogo, forceCat = tests$forceCat[i], ggObj = tests$ggObj[i], geom_raster = !tests$anno[i], ggLayer = tests$ggLayer[i]))            
-            tinfo <- paste0("forceCat=", tests[,1], ", anno=", tests[,2], ", ggLayer=", tests[,3], ", ggObj=", tests[,4])
+            tinfo  <- paste0("forceCat=", tests[,1], ", anno=", tests[,2], ", ggLayer=", tests[,3], ", ggObj=", tests[,4])
             
             ## Annotation vs geom_raster    
             for(s in which(with(tests, ggObj & !ggLayer))) expect_is(builds[[s]], c("gg", "ggplot"), info = tinfo[s])
@@ -31,6 +32,30 @@ test_that("ggR returns proper ggplot2 classes or data.frames", {
 
 
 
+test_that("ggR works with single valued rasters", {
+            r <- raster(vals = 1, ncol = 2, nrow = 1)[[c(1,1,1)]]
+            suppressWarnings(r[[1]][]<- NA)
+            r[[2]][]<- 17
+            r[[3]][]<- c(NA,2)
+            
+            for(i in 1:3) expect_is(ggR(r,i), c("gg", "ggplot2"))
+            for(i in 1:3) expect_is(ggR(r,i,geom_raster = TRUE), c("gg", "ggplot2"))
+            
+            ## All NAs
+            expect_equal(sum(is.na(ggR(r,1, ggObj = FALSE)[,3:4])), 4)  ## all na
+            
+            ## Single value
+            gp <- ggR(r, 2, ggObj = FALSE)
+            expect_equal(unique(gp[, "fill"]), "#FFFFFFFF")  ## fill colour
+            expect_equal(unique(gp[, 3]), 17) ## actual value
+            
+            ## Single values + NAs
+            gp <- ggR(r, 3, ggObj = FALSE)
+            expect_equal(gp[,"fill"], c(NA, "#FFFFFFFF"))  ## fill colour
+            expect_equal(gp[,3], c(NA, 2)) ## actual values
+        })
+
+
 test_that("ggRGB returns proper ggplot2 classes or data.frames", {
             data(rlogo) 
             
